puffbird.CallableContainer
==========================

.. currentmodule:: puffbird

.. autoclass:: CallableContainer

   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      CallableContainer.__call__
      CallableContainer.add




   

